BBCharacteristic class
Constructors
-
BBCharacteristic({required String deviceId, required String serviceId, required String id, required String? name, required Set<
BBCharacteristicProperty> properties})
Properties
- data → Uint8List
-
no setter
-
dataStream
→ Stream<
Uint8List> -
no setter
- deviceId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String?
-
final
- notifyEnabled → bool
-
no setter
-
notifyEnabledStream
→ Stream<
bool> -
no setter
-
properties
→ Set<
BBCharacteristicProperty> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< Uint8List> -
subscribe(
) → Future -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
) → Future -
write(
{required Uint8List data, bool withResponse = false}) → Future
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited